@@ -1,10 +1,12 @@
 from pokeman.pokeman import Pokeman
 from pokeman.amqp_resources.globals import Exchange, RoutingKey, Queue
+from pokeman.amqp_resources import heapq
 from pokeman.composite import ConnectionParameters, Connection, BasicConfig
-from pokeman import coatings
+from pokeman.coatings import BasicMessage, BasicMessageConsumer, PollingConsumer, SelectiveConsumer, Ptypes
 
 
-__version__ = '0.1.2'
+
+__version__ = '0.1.6'
 
 
 __all__ = [
@@ -16,7 +18,7 @@ __all__ = [
     'ConnectionParameters', 'Connection', 'BasicConfig',
 
     # EIP
-    'coatings']
+    'BasicMessage', 'BasicMessageConsumer', 'PollingConsumer', 'SelectiveConsumer', 'Ptypes']
 
 import platform
 
